#-*- coding: utf-8 -*-
# memaker.py - A gtk based avatar creation program.
# Copyright 2008 The MeMaker Project
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. See the file LICENSE.
# If not, see <http://www.gnu.org/licenses/>.

import logging
import os
import webbrowser
from gettext import gettext as _

LAUNCHPADLIB_INSTALLED = False
try:
    from launchpadlib.launchpad import Launchpad
    from launchpadlib.credentials import Credentials
    LAUNCHPADLIB_INSTALLED = True
except ImportError:
    logging.info(_("python-launchpadlib not found!"))

class MeMakerLaunchpad:
    def __init__(self):
        self.credentials = None

    def load_auth(self, authorization_file):
        self.credentials = Credentials()
        self.credentials.load(open(authorization_file))

    def get_auth1(self):
        self.credentials = Credentials(consumer_name="memaker")
        token = self.credentials.get_request_token(
                                    web_root='https://launchpad.net/')
        webbrowser.open(token)
        
    def get_auth2(self, authorization_file):
        self.credentials.exchange_request_token_for_access_token(
                                    web_root='https://launchpad.net/')
        self.credentials.save(file(authorization_file, "w"))

    def get_mugshot_data(self, config_dir, cache_dir):
        authorization_file = os.path.join(config_dir, "launchpad_auth")
        self.load_auth(authorization_file)
        launchpad = Launchpad(self.credentials, cache=cache_dir, 
                        service_root='https://api.launchpad.net/beta/')
        mugshot = launchpad.me.mugshot
        return mugshot

    def get_mugshot(self, config_dir, cache_dir):
        mugshot = self.get_mugshot_data(config_dir, cache_dir)
        return mugshot.open("r").read()
        
    def set_mugshot(self, config_dir, cache_dir, new_mugshot_data):
        mugshot = self.get_mugshot_data(config_dir, cache_dir)
        mugshot_handle = mugshot.open("w", "image/png", "mugshot.png")
        mugshot_handle.write(new_mugshot_data)
        mugshot_handle.close()
        return True
    
    def check_installed(self):
        return LAUNCHPADLIB_INSTALLED
