#-*- coding: utf-8 -*-
# memaker.py - A gtk based avatar creation program.
# Copyright 2008 The MeMaker Project
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. See the file LICENSE.
# If not, see <http://www.gnu.org/licenses/>.

import logging
import os
import shutil

from xdg import BaseDirectory as xdg

class MeMakerPaths:
    def __init__(self, data_dir):
        self.data_dir = data_dir
        self.create_directory_structure()
        self.clear_it = os.path.join(data_dir, "clearIt.svg")
        self.themes_dir = os.path.join(data_dir, "themes")
        self.old_mugshot_file = os.path.join(self.cache_home,
                                            'launchpad_mugshot_old.png')
        self.dnd_avatar_svg = os.path.join(self.cache_home, 'avatar.svg')
        self.face_backup = os.path.join(self.cache_home, '.face')
        self.face = os.path.expanduser("~/.face")
        self.launchpad_auth_file = os.path.join(self.config_home, 
                                                    "launchpad_auth")
        self.pickled_heads_file = os.path.join(self.cache_home, 
                                                    "pickledHeads")
        self.home = os.path.expanduser("~/")
        if os.path.isdir(os.path.join(self.home, ".purple")):
            self.pidgin_dir = os.path.join(self.home, ".purple")
            self.pidgin_icons_dir = os.path.join(self.pidgin_dir, "icons")
        
        
    def create_directory_structure(self):
        """
        Create the default directory structure if not there now....
        """
        for type in ["data", "config", "cache"]:
            xdg_variable = getattr(xdg, "xdg_%s_home" % type)
            setattr(self, type+"_home", os.path.join(xdg_variable, "memaker"))
            if type != "data":
                self.directory_check(getattr(self, type+"_home"))
            else:
                self.directory_check(os.path.join(getattr(self, type+"_home"),
                                                "themes"))
                                                
        if os.path.isdir(os.path.expanduser('~/.MeMaker')):
            shutil.rmtree(os.path.expanduser('~/.MeMaker'))
            
    def directory_check(self, new_directory):
        """
        Check if directory exist and create it if it doesn't
        """
        if os.path.isdir(new_directory):
            pass
        elif os.path.isfile(new_directory):
            raise OSError("a file with the same name as the desired " \
                          "dir, '%s', already exists." % new_directory)
        else:
            head, tail = os.path.split(new_directory)
            if head and not os.path.isdir(head):
                logging.info("A required directory was not found .... making:" + head)
                os.makedirs(head)
            if tail:
                logging.info("A required directory was not found .... making:" + new_directory)
                os.makedirs(new_directory)
