#
#       dialog.py
#       
#       Copyright 2009 Andrew <rugby471@gmail.com>
#       
#       This program is free software; you can redistribute it and/or modify
#       it under the terms of the GNU General Public License as published by
#       the Free Software Foundation; either version 2 of the License, or
#       (at your option) any later version.
#       
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#       GNU General Public License for more details.
#       
#       You should have received a copy of the GNU General Public License
#       along with this program; if not, write to the Free Software
#       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#       MA 02110-1301, USA.

import gtk
from gettext import gettext as _

class MessageDialog(gtk.MessageDialog):
    """Message dialog with optional details expander"""
    def __init__(self,
                 parent=None, 
                 title="", 
                 primary=None, 
                 secondary=None, 
                 details=None,
                 treeview=None,
                 preset=None,
                 buttons=gtk.BUTTONS_OK, 
                 type=gtk.MESSAGE_INFO):
                     
        gtk.MessageDialog.__init__(self, parent, 0, type, buttons, primary)
        self.set_title(title)
        self.set_resizable(True)
        # Disable annoying behavior
        self.set_property("skip-pager-hint", False)
        self.set_property("skip-taskbar-hint", False)
        if secondary:
            self.format_secondary_markup(secondary)
        if treeview:
            self.get_image().set_from_stock(gtk.STOCK_SAVE_AS, 6)
            self.get_content_area().pack_start(treeview)
            setattr(self, "treeview", treeview)
        if details:
            textview = gtk.TextView()
            textview.set_size_request(400, 200)
            textview.set_wrap_mode(gtk.WRAP_WORD_CHAR)
            textview.get_buffer().set_text(str(details))
            scroll = gtk.ScrolledWindow()
            scroll.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
            scroll.add(textview)
            expand = gtk.Expander(_("Details"))
            expand.add(scroll)
            expand.show_all()
            self.get_content_area().pack_start(expand)
        
def messagedialog(parent=None, 
                  title="", 
                  primary=None, 
                  secondary=None, 
                  details=None,
                  treeview=None,
                  buttons=gtk.BUTTONS_OK, 
                  type=gtk.MESSAGE_INFO):
    """ run a dialog """
    dialog = MessageDialog(parent=parent, title=title,
                                  primary=primary, secondary=secondary,
                                  details=details, treeview=treeview, 
                                  type=type, buttons=buttons)
    
    dialog.show_all()                                      
    result = dialog.run()
    if treeview:
        selected = dialog.treeview.get_selection().get_selected_rows()
        dialog.destroy()
        return result, selected
    dialog.destroy()
    return result

def error(parent, primary, secondary, details=None):
    """ show a untitled error dialog """
    return messagedialog(parent=parent,
                         title=_("MeMaker - Error"),
                         primary=primary, 
                         secondary=secondary,
                         details=details,
                         type=gtk.MESSAGE_ERROR)
                         
def save_pidgin(parent, primary, treeview, secondary=None):
    """ show a untitled error dialog """
    return messagedialog(parent=parent,
                         title=_("MeMaker - Save"),
                         primary=primary, 
                         secondary=secondary,
                         treeview=treeview,
                         type=gtk.MESSAGE_INFO,
                         buttons=gtk.BUTTONS_OK_CANCEL
                         )
                        


